@@ -29,12 +29,12 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QMenu>
+#include <QTextCursor>
 
 TextEditor::TextEditor(QWidget *parent) :
     QTextEdit(parent), spellChecker(this)
 {
     hasCopy = false;
-    mTextSaved = true;
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenuRequested(QPoint)));
     connect(document(), SIGNAL(cursorPositionChanged(const QTextCursor &)), this, SLOT(updateSP()));
@@ -46,11 +46,6 @@ TextEditor::~TextEditor()
 {
 }
 
-bool TextEditor::textSaved()
-{
-    return mTextSaved;
-}
-
 bool TextEditor::spellCheck(const QString &lang)
 {
     spellChecker.setLanguage(lang);
@@ -72,36 +67,6 @@ bool TextEditor::hasDict(const QString &shname)
     return spellChecker.hasDict(shname);
 }
 
-void TextEditor::saveText()
-{
-    Settings * settings = Settings::instance();
-    QString filter;
-    if (settings->getOutputFormat() == "text")
-        filter = trUtf8("Text Files (*.txt)");
-    else
-        filter = trUtf8("HTML Files (*.html)");
-    QFileDialog dialog(this,
-                       trUtf8("Save Text"), settings->getLastOutputDir(), filter);
-    if (settings->getOutputFormat() == "text")
-        dialog.setDefaultSuffix("txt");
-    else
-        dialog.setDefaultSuffix("html");
-    dialog.setAcceptMode(QFileDialog::AcceptSave);
-    if (dialog.exec()) {
-        QStringList fileNames;
-        fileNames = dialog.selectedFiles();
-        settings->setLastOutputDir(dialog.directory().path());
-        QFile textFile(fileNames.at(0));
-        textFile.open(QIODevice::ReadWrite | QIODevice::Truncate);
-        if (settings->getOutputFormat() == "text")
-            textFile.write(toPlainText().toUtf8());
-        else
-            saveHtml(&textFile);
-        textFile.close();
-        mTextSaved = true;
-    }
-
-}
 
 void TextEditor::keyPressEvent(QKeyEvent *e)
 {
@@ -134,7 +99,7 @@ void TextEditor::wheelEvent(QWheelEvent *e)
 
 void TextEditor::replaceWord()
 {
-    QAction * action =  (QAction *) sender();
+    QAction *action =  (QAction *) sender();
     QTextCursor cursor = textCursor();
     cursor.select(QTextCursor::WordUnderCursor);
     cursor.removeSelectedText();
@@ -148,8 +113,7 @@ void TextEditor::copyAvailable(bool yes)
 
 void TextEditor::textChanged()
 {
-    mTextSaved = !(toPlainText().count());
-    Settings * settings = Settings::instance();
+    Settings *settings = Settings::instance();
     QFont f(font());
     f.setPointSize(settings->getFontSize());
     setFont(f);
@@ -178,10 +142,20 @@ void TextEditor::saveHtml(QFile *file)
     file->write(text.toAscii());
 }
 
+void TextEditor::globalReplace(const QString &what, const QString &with)
+{
+    moveCursor(QTextCursor::Start);
+    while (find(what)) {
+        QTextCursor cursor = textCursor();
+        cursor.removeSelectedText();
+        cursor.insertText(what);
+    }
+}
+
 void TextEditor::contextMenuRequested(const QPoint &point)
 {
     QAction *action;
-    QMenu * menu = new QMenu(this);
+    QMenu *menu = new QMenu(this);
     QStringList sl = spellChecker.suggestions();
     //if (sl.count() == 0) {
 
@@ -228,7 +202,7 @@ void TextEditor::contextMenuRequested(const QPoint &point)
     if (sl.count() > 0)
         menu->addSeparator();
     foreach(QString str, sl) {
-        QAction * action = menu->addAction(str);
+        QAction *action = menu->addAction(str);
         connect(action, SIGNAL(triggered()), this, SLOT(replaceWord()));
     }
     menu->exec(mapToGlobal(point));
@@ -237,7 +211,7 @@ void TextEditor::contextMenuRequested(const QPoint &point)
 
 void TextEditor::enlargeFont()
 {
-    Settings * settings = Settings::instance();
+    Settings *settings = Settings::instance();
     int fontSize = font().pointSize();
     fontSize++;
     QFont f(font());
@@ -248,7 +222,7 @@ void TextEditor::enlargeFont()
 
 void TextEditor::decreaseFont()
 {
-    Settings * settings = Settings::instance();
+    Settings *settings = Settings::instance();
     int fontSize = font().pointSize();
     if (fontSize > 1) fontSize--;
     QFont f(font());
@@ -259,7 +233,7 @@ void TextEditor::decreaseFont()
 
 void TextEditor::updateSP()
 {
-    Settings * settings = Settings::instance();
+    Settings *settings = Settings::instance();
     if (settings->getCheckSpelling())
         spellChecker.checkWord();
 }
